summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/bytestream.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/bytestream.cpp')
-rw-r--r--kopete/protocols/oscar/liboscar/bytestream.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/oscar/liboscar/bytestream.cpp b/kopete/protocols/oscar/liboscar/bytestream.cpp
index f2fb8e51..87603c76 100644
--- a/kopete/protocols/oscar/liboscar/bytestream.cpp
+++ b/kopete/protocols/oscar/liboscar/bytestream.cpp
@@ -63,9 +63,9 @@ public:
};
//!
-//! Constructs a ByteStream object with tqparent \a tqparent.
-ByteStream::ByteStream(TQObject *tqparent)
-:TQObject(tqparent)
+//! Constructs a ByteStream object with parent \a parent.
+ByteStream::ByteStream(TQObject *parent)
+:TQObject(parent)
{
d = new Private;
}